@@ -44,11 +44,7 @@ from .task import (
     TaskSpec,
     TaskStatus,
 )
-from .volume import (
-    GCS,
-    NFS,
-    Volume,
-)
+from .volume import GCS, NFS, Volume
 
 __all__ = (
     "CreateJobRequest",
